@@ -4,7 +4,7 @@ use warnings;
 package OS::Package::Artifact;
 
 # ABSTRACT: OS::Package::Artifact object.
-our $VERSION = '0.2.1'; # VERSION
+our $VERSION = '0.2.2'; # VERSION
 
 use Moo;
 use Types::Standard qw( Str InstanceOf );
@@ -45,7 +45,7 @@ OS::Package::Artifact - OS::Package::Artifact object.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 METHODS
 
@@ -75,7 +75,7 @@ Temporary directory to extract and stage artifact.
 
 =head1 AUTHOR
 
-James F Wilkus <jfwilkus@mac.com>
+James F Wilkus <jfwilkus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
