@@ -4,7 +4,7 @@ use warnings;
 package OS::Package::Config;
 
 # ABSTRACT: Load OS::Package configuration object.
-our $VERSION = '0.2.1'; # VERSION
+our $VERSION = '0.2.2'; # VERSION
 
 use base qw(Exporter);
 use Env qw( $HOME );
@@ -49,11 +49,11 @@ OS::Package::Config - Load OS::Package configuration object.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 AUTHOR
 
-James F Wilkus <jfwilkus@mac.com>
+James F Wilkus <jfwilkus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
