@@ -8,7 +8,7 @@ use base qw(Exporter);
 use Log::Log4perl;
 
 # ABSTRACT: Load OS::Package LOGGER object.
-our $VERSION = '0.2.1'; # VERSION
+our $VERSION = '0.2.2'; # VERSION
 
 our @EXPORT = qw( $LOGGER );
 
@@ -30,11 +30,11 @@ OS::Package::Log - Load OS::Package LOGGER object.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 AUTHOR
 
-James F Wilkus <jfwilkus@mac.com>
+James F Wilkus <jfwilkus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
