@@ -4,7 +4,7 @@ use warnings;
 package OS::Package::Maintainer;
 
 # ABSTRACT: Default Abstract Description, Please Change.
-our $VERSION = '0.2.1'; # VERSION
+our $VERSION = '0.2.2'; # VERSION
 
 use Moo;
 use Types::Standard qw( Str Enum );
@@ -50,7 +50,7 @@ OS::Package::Maintainer - Default Abstract Description, Please Change.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 METHODS
 
@@ -60,7 +60,7 @@ Returns string "Author (nickname) <email>".
 
 =head1 AUTHOR
 
-James F Wilkus <jfwilkus@mac.com>
+James F Wilkus <jfwilkus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
