@@ -4,7 +4,7 @@ use warnings;
 package OS::Package::Plugin::Linux::RPM;
 
 # ABSTRACT: Default Abstract Description, Please Change.
-our $VERSION = '0.2.1'; # VERSION
+our $VERSION = '0.2.2'; # VERSION
 
 use Moo;
 
@@ -24,11 +24,11 @@ OS::Package::Plugin::Linux::RPM - Default Abstract Description, Please Change.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 AUTHOR
 
-James F Wilkus <jfwilkus@mac.com>
+James F Wilkus <jfwilkus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
