@@ -4,7 +4,7 @@ use warnings;
 package OS::Package::Plugin::Solaris::SVR4;
 
 # ABSTRACT: Default Abstract Description, Please Change.
-our $VERSION = '0.2.1'; # VERSION
+our $VERSION = '0.2.2'; # VERSION
 
 use Cwd;
 use Moo;
@@ -266,7 +266,7 @@ OS::Package::Plugin::Solaris::SVR4 - Default Abstract Description, Please Change
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 METHODS
 
@@ -280,7 +280,7 @@ Returns file extension for SVR4 package.
 
 =head1 AUTHOR
 
-James F Wilkus <jfwilkus@mac.com>
+James F Wilkus <jfwilkus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
