@@ -4,7 +4,7 @@ use warnings;
 package OS::Package::Role::Clean;
 
 # ABSTRACT: Provides the clean method.
-our $VERSION = '0.2.1'; # VERSION
+our $VERSION = '0.2.2'; # VERSION
 
 use Path::Tiny;
 use OS::Package::Log;
@@ -44,7 +44,7 @@ OS::Package::Role::Clean - Provides the clean method.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 METHODS
 
@@ -54,7 +54,7 @@ Provides method to clean the fakeroot directory.
 
 =head1 AUTHOR
 
-James F Wilkus <jfwilkus@mac.com>
+James F Wilkus <jfwilkus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
