@@ -4,7 +4,7 @@ use warnings;
 package OS::Package::Role::Prune;
 
 # ABSTRACT: Default Abstract Description, Please Change.
-our $VERSION = '0.2.1'; # VERSION
+our $VERSION = '0.2.2'; # VERSION
 
 use OS::Package::Log;
 use Path::Tiny;
@@ -70,7 +70,7 @@ OS::Package::Role::Prune - Default Abstract Description, Please Change.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 METHODS
 
@@ -80,7 +80,7 @@ Attempts to clean workdir and fakeroot directories.
 
 =head1 AUTHOR
 
-James F Wilkus <jfwilkus@mac.com>
+James F Wilkus <jfwilkus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
